/*----------------------------------------------------------------------------*\
Application
	computeTorque

Description
	computes the pressure torque on a given surface

\*---------------------------------------------------------------------------*/

// Main program:

#include "fvCFD.H"
#include "MRFZonesDrg.H"

void computeTorq(word patchName, fvMesh& mesh, volScalarField& p, const dimensionedVector& Omega, const dimensionedVector& origin);

int main(int argc, char *argv[])
{

#   include "setRootCase.H"

#   include "createTime.H"
#   include "createMesh.H"
#   include "createFields.H"
	
	MRFZones mrf(mesh);
	
	forAll(mrf,i)
	{
		const wordList& patchNames = mrf[i].getPatchNames();
		const dimensionedVector& origin = mrf[i].getOrigin();
		const dimensionedVector& Omega = mrf[i].getOmega();
		forAll(patchNames,j)
			computeTorq(patchNames[j], mesh, p, Omega, origin);
	}
	
	return 1;	
	
}

void computeTorq(word patchName, fvMesh& mesh, volScalarField& p, const dimensionedVector& Omega, const dimensionedVector& origin)
{

	// get the label for the requested patch
 	label patchID = mesh.boundaryMesh().findPatchID(patchName);
	
	if (-1 == patchID)
	{
		Info << "no patch named "+patchName << endl <<"Available patches:" << endl;
		error err("Error!\n");

		//access boundary elements
		const fvPatchList& patches = mesh.boundary();
		
		//loop over boundaries
		forAll(patches, patchI)
		{ 	
			Info << patches[patchI].name() << endl;
		}
		
		err.exit();
	}
	
	const fvPatch& cPatch = mesh.boundary()[patchID];
	
//	dimensionedVector torque("torque",dimensionSet(1,2,-2,0,0,0,0),vector::zero);
//	dimensionedScalar pref("pref",dimensionSet(1,-1,-2,0,0,0,0),101325.0);
	vector torque(0,0,0);
	vector r0 = origin.value();
	scalar pref = 101325.0;
	
/*	forAll(cPatch,faceI)
	{
		scalar pabs = p.boundaryField()[patchID][faceI]+101325;
		vector Area = cPatch.Sf()[faceI];
		vector r = cPatch.Cf()[faceI]-r0;
		vector force = pabs*Area;
		torque = torque+(r^force);
	}
*/	

	torque = sum((cPatch.Cf()-r0)^((p.boundaryField()[patchID]+pref)*cPatch.Sf()));
	Info << "torque(" << patchName << "): " << torque << "[Nm]; power: " << torque*Omega.value() << "[W]" << endl;
}

